/***************************************************************************
                          items.h  -  description
                             -------------------
    copyright            : (C) 2003 by Willy De la Court
    email                : willy.delacourt@pandora.be
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2 as     *
 *   published by the Free Software Foundation                             *
 *                                                                         *
 ***************************************************************************/

#ifndef _ITEMS_H_
#define _ITEMS_H_

#include <qstring.h>
#include "configwidget.h"
#include "oneitem_ui.h"
#include "oneitemtime_ui.h"
#include "rangesitem_ui.h"
#include "subnetitem_ui.h"
#include "hostitem_ui.h"
#include "optionsitem_ui.h"
#include "addsubnet_ui.h"
#include "addhost_ui.h"
#include "leasesitem_ui.h"
#include "mlistviewitem.h"
#include "mlistview.h"
#include "dataclasses.h"
#include "mtextedit.h"

class oneDataItem : public oneItem_UI
{
	Q_OBJECT

public:
	oneDataItem( MListView *listView, QList<dataItem> *parentList, dataItem *parserDataItem, QWidget *parent = 0, const char *name = 0 );
	oneDataItem( MListViewItem *listView, QString listViewItemText, dataItem *parserDataItem, QWidget *parent = 0, const char *name = 0 );
	~oneDataItem();

	MListViewItem *thisListViewItem;

public slots:
	void updateData();

protected:
	dataItem *thisDataItem;
	QList<dataItem> *thisParentList;
};

class oneDataItemTime : public oneItemTime_UI
{
	Q_OBJECT

public:
	oneDataItemTime( MListView *listView, QList<dataItem> *parentList, dataItem *parserDataItem, QWidget *parent = 0, const char *name = 0 );
	~oneDataItemTime();

	MListViewItem *thisListViewItem;

public slots:
	void updateData();

protected:
	dataItem *thisDataItem;
	QList<dataItem> *thisParentList;
};

class rangeDataItem : public ConfigWidget
{
	Q_OBJECT

public:
	rangeDataItem( MListView *listViewItem, QList<rangeItem> *parentList, rangeItem *parserDataItem );

	~rangeDataItem();

	MListViewItem *thisListViewItem;
	rangeItem *thisDataItem;
	QList<rangeItem> *thisParentList;
};

class rangesDataItem : public rangesItem_UI
{
	Q_OBJECT

public:
	rangesDataItem( MListViewItem *listViewItem, QString listViewItemText, QList<rangeItem> *parserDataItem = 0, QWidget *parent = 0, const char *name = 0 );
	~rangesDataItem() {};

	MListViewItem *thisListViewItem;
	MListViewItem *rangesListViewItem;
	MListViewItem *currentListViewItem;
	QList<rangeItem> *thisDataItem;

private slots:
	void selectionHighlighted(QListViewItem *i);
	void remove();
	void addNew();
	void updateData();
};

class subnetDataItem : public subnetItem_UI
{
	Q_OBJECT

public:
	subnetDataItem( MListViewItem *listViewItem, QString listViewItemText, QList<subnetItem> *parentList, subnetItem *parserDataItem, QWidget *parent = 0, const char *name = 0 );
	~subnetDataItem();

	MListViewItem *thisListViewItem;
	subnetItem *thisDataItem;
	
private slots:
	void updateData();
	void remove();

protected:
	QList<subnetItem> *thisParentList;
};

class hostDataItem : public hostItem_UI
{
	Q_OBJECT

public:
	hostDataItem( MListViewItem *listViewItem, QString listViewItemText, QList<hostItem> *parentList, hostItem *parserDataItem, QWidget *parent = 0, const char *name = 0 );
	~hostDataItem();

	MListViewItem *thisListViewItem;
	hostItem *thisDataItem;
	
private slots:
	void updateData();
	void remove();

protected:
	QList<hostItem> *thisParentList;
};

class addSubnetDataItem : public addSubnetItem_UI
{
	Q_OBJECT

public:
	addSubnetDataItem( MListViewItem *listViewItem, QString listViewItemText, QList<subnetItem> *parserDataItem, QWidget *parent = 0, const char *name = 0 );
	~addSubnetDataItem() {};

	MListViewItem *thisListViewItem;
	QList<subnetItem> *thisDataItem;

private slots:
	void addSubnet();
};

class addHostDataItem : public addHostItem_UI
{
	Q_OBJECT

public:
	addHostDataItem( MListViewItem *listViewItem, QString listViewItemText, QList<hostItem> *parserDataItem, QWidget *parent = 0, const char *name = 0 );
	~addHostDataItem() {};

	MListViewItem *thisListViewItem;
	QList<hostItem> *thisDataItem;

private slots:
	void addHost();
};

class optionsItem : public optionsItem_UI
{
	Q_OBJECT

public:
	optionsItem( MListViewItem *listViewItem, QString listViewItemText, QList<dataItem> *parserDataItem, QWidget *parent = 0, const char *name = 0 );
	optionsItem( QList<dataItem> *parserDataItem, QWidget *parent = 0, const char *name = 0 );
	~optionsItem() {};

	void addHostOptions();
	void init();

	MListViewItem *thisListViewItem;
	MListViewItem *currentListViewItem;
	QList<dataItem> *thisDataItem;
	ConfigWidget *configWidget;
	ConfigWidget *dummyConfigWidget;

public slots:
	void emitChanged(bool state);
	void remove();
	void add();

private slots:
	void selectionHighlighted(QListViewItem *i);

};

class leasesItem : public leasesItem_UI
{
	Q_OBJECT

public:
	leasesItem( MListViewItem *listViewItem, QString listViewItemText, QList<leaseItem> *parserDataItem, QWidget *parent = 0, const char *name = 0 );
	~leasesItem() {};

	MListViewItem *thisListViewItem;
	MListViewItem *currentListViewItem;
	QList<leaseItem> *thisDataItem;

//public slots:
//	void emitChanged(bool state);

//private slots:
//	void selectionHighlighted(QListViewItem *i);

};

#endif
