%{
/***************************************************************************
                          leasegrammer.y  -  description
                             -------------------
    copyright            : (C) 2002 by Willy De la Court
    email                : willy.delacourt@pandora.be
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2 as     *
 *   published by the Free Software Foundation                             *
 *                                                                         *
 ***************************************************************************/


#include <stdio.h>
#include <string.h>
#include <qstringlist.h>
#include "confparser.h"
#include "leaseparser.h"

#define YYSTYPE char *
#define YYDEBUG 1
#define YYMAXDEPTH 0
#define YYPARSE_PARAM lease_parser

extern int yylex(void);
extern int lease_lineno;

dataItem *lease_data = 0L;
leaseItem *currentLease = 0L;
LeaseParser *lease_p = 0;

void yyerror(const char *str)
{
	if( lease_p )
		lease_p->addSyntaxError( lease_lineno );
	fprintf(stderr,"error: %s in line %d\n", str, lease_lineno);
}

void lease_init( void *lease_parser )
{
	lease_p = static_cast<LeaseParser *>(lease_parser);
}

/*void lease_add_option(const char *txt, const char *val, void *lease_parser)
{
	lease_data = new dataItem(txt, val);
	if( currentLease )
		currentLease->addOption(lease_data);
	printf("*%s %s*\n", txt, val);
}*/

#define INIT()						lease_init(lease_parser);
#define ADD_LEASE(ip)				currentLease = new leaseItem(ip); \
									LeaseParser *p = static_cast<LeaseParser *>(lease_parser); \
									p->addLease(currentLease); \
									lease_data = currentLease;

#define ADD_STARTS(val1, val2, val3)	if( currentLease ) { \
											currentLease->itemStartsDay = val1; \
											currentLease->itemStartsDate = val2; \
											currentLease->itemStartsTime = val3; \
										}

#define ADD_ENDS(val1, val2, val3)		if( currentLease ) { \
											currentLease->itemEndsDay = val1; \
											currentLease->itemEndsDate = val2; \
											currentLease->itemEndsTime = val3; \
										}

#define ADD_MAC(val)					if( currentLease ) { currentLease->itemMAC = val; }
#define ADD_UID(val)					if( currentLease ) { currentLease->itemUid = val; }
#define ADD_CLIENTHOSTNAME(val)			if( currentLease ) { currentLease->itemClientHostname = val; }
#define ADD_HOSTNAME(val)				if( currentLease ) { currentLease->itemHostname = val; }
#define ADD_ABANDONED()					if( currentLease ) { currentLease->itemAbandoned = true; }
#define SET_COMMENT(val)				if(lease_data) \
											lease_data->setComment(val); \
										//printf("comment %s\n", val);

%}

%token '{'
%token '}'
%token ';'
%token '.'
%token '-'

%token LEASE
%token STARTS
%token ENDS
%token UID
%token HARDWARE
%token ETHERNET
%token CLIENTHOSTNAME
%token HOSTNAME
%token ABANDONED
%token QUOTE
%token IP
%token NUMBER
%token MAC
%token UIDCODE
%token DOMAIN
%token COMMENT
%token WORD
%token DATE
%token TIME
%%

file:
	  { INIT(); }  /* empty */
	| file all
	;

all:
	  leases
	| comment
	| error '}' 					{ yyclearin; yyerrok; }
	;

leases:
	LEASE IP { ADD_LEASE($2); } comments
	'{' comments
		options
	'}' comments
	;

options:
	  /* empty */
	| options option comments
	| error ';' 					{ yyclearin; yyerrok; }
	| error '}' 					{ yyclearin; yyerrok; }
	;

option:
	  STARTS NUMBER DATE TIME ';'			{ ADD_STARTS($2, $3, $4); }
	| ENDS NUMBER DATE TIME ';'				{ ADD_ENDS($2, $3, $4); }
	| UID UIDCODE ';'						{ ADD_UID($2); }
	| CLIENTHOSTNAME QUOTE WORD QUOTE ';'	{ ADD_CLIENTHOSTNAME($3); }
	| HOSTNAME QUOTE WORD QUOTE ';'			{ ADD_HOSTNAME($3); }
	| HARDWARE ETHERNET MAC ';'				{ ADD_MAC($3); }
	| ABANDONED ';'							{ ADD_ABANDONED(); }
	;

comments:
	  /* empty */
	| comments comment
	;

comment:
	COMMENT				{ SET_COMMENT($1); }
	;
%%
