%option case-insensitive
%option noyywrap
%option 8bit
%{
/***************************************************************************
                          leasetokens.flex  -  description
                             -------------------
    copyright            : (C) 2002 by Willy De la Court
    email                : willy.delacourt@pandora.be
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2 as     *
 *   published by the Free Software Foundation                             *
 *                                                                         *
 ***************************************************************************/

#define YYSTYPE char *

#include "leasegrammer.h"
#include <string.h>

static int my_lease_input( char *buffer, int max_size );
#define YY_INPUT( buffer, result, max_size ) { result = my_lease_input( buffer, max_size ); }

int lease_lineno;
extern YYSTYPE lease_yylval;
int lease_yypos = 0;
const char *lease_lexinput;

//#define DEBUG 1
#ifdef DEBUG
#define PDEBUG(x, y) printf(x, y)
#else
#define PDEBUG(x, y) 
#endif

#define RETURN(val) {PDEBUG("[%s] ", yytext); return val;}
#define RETURNVAL(val, txt) {lease_yylval = strdup(yytext); PDEBUG(txt, yytext); return val; }
%}
%%

"lease"				RETURN(LEASE);
"starts"			RETURN(STARTS);
"ends"				RETURN(ENDS);
"uid"				RETURN(UID);
"hardware"			RETURN(HARDWARE);
"ethernet"			RETURN(ETHERNET);
"client-hostname"	RETURN(CLIENTHOSTNAME);
"abandoned"			RETURN(ABANDONED);
"hostname"			RETURN(HOSTNAME);
[0-9]+\/[0-9]+\/[0-9]+		RETURNVAL(DATE, "DATE[%s]");
[0-9]+\:[0-9]+\:[0-9]+		RETURNVAL(TIME, "TIME[%s]");
[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+		RETURNVAL(IP, "IP[%s]");
[0-9]+|\-[0-9]+						RETURNVAL(NUMBER, "NUMBER[%s]");
[a-zA-Z0-9][a-zA-Z0-9-]*			RETURNVAL(WORD, "WORD[%s]");
[a-zA-Z0-9][a-zA-Z0-9-]*\.[a-zA-Z0-9][a-zA-Z0-9.-]*	RETURNVAL(DOMAIN, "DOMAIN[%s]");
[a-fA-F0-9][a-fA-F0-9]\:[a-fA-F0-9][a-fA-F0-9]\:[a-fA-F0-9][a-fA-F0-9]\:[a-fA-F0-9][a-fA-F0-9]\:[a-fA-F0-9][a-fA-F0-9]\:[a-fA-F0-9][a-fA-F0-9]	RETURNVAL(MAC, "MAC[%s]");
[a-fA-F0-9][a-fA-F0-9]\:[a-fA-F0-9][a-fA-F0-9]\:[a-fA-F0-9][a-fA-F0-9]\:[a-fA-F0-9][a-fA-F0-9]\:[a-fA-F0-9][a-fA-F0-9]\:[a-fA-F0-9][a-fA-F0-9]\:[a-fA-F0-9][a-fA-F0-9]	RETURNVAL(UIDCODE, "UID[%s]");
"\."		RETURN('.');
"-"			RETURN('-');
"\""		RETURN(QUOTE);
";"			RETURN(';');
"{"			RETURN('{');
"}"			RETURN('}');
#[^\n]+\n	lease_lineno++; RETURNVAL(COMMENT, "COMMENT[%s]");
\n              	/* ignore EOL */ PDEBUG("\n", ""); lease_lineno++;
[ \t]+          	/* ignore whitespace */;
.			return( (int) yytext[0]);
%%


static int my_lease_input( char *buffer, int max_size )
{
	int n = 0;
	char *inp_str = (char *) lease_lexinput + lease_yypos;
	n = ( int ) strlen( inp_str );
 
	if ( n > max_size )
	{
		lease_yypos = lease_yypos + max_size;
		n = max_size;
	}
	else
		lease_yypos = lease_yypos + n;
	memcpy( buffer, inp_str, n );
	return n;
}
